@@ -132,24 +132,24 @@ sub log {
 sub query_execute {
     my($self, $sth, @qmarks) = @_;
 
+    my $errstr = "[no error]";
+
     for my $attempt (0..$self->{reconnect_attempts}) {
         #warn "Exe: @qmarks"; # TODO
         if(! $sth->execute(@qmarks)) {
 
+                  # save errstr because ping() would override it [RT 56145]
+                $errstr = $self->{dbh}->errstr();
+
                 # Exe failed -- was it because we lost the DB
                 # connection?
                 if($self->{dbh}->ping()) {
                     # No, the connection is ok, we failed because there's
                     # something wrong with the execute(): Bad SQL or 
                     # missing parameters or some such). Abort.
-                    croak "Log4perl: DBI appender error: '" .
-                          $self->{dbh}->errstr() . 
-                          "'";
+                    croak "Log4perl: DBI appender error: '$errstr'";
                 }
 
-                # warn "Log4perl: DBI->execute failed $DBI::errstr, \n".
-                #                  "on $self->{SQL}\n@qmarks";
-                #warn "Exe: failed: $DBI::errstr"; # TODO
                 if($attempt == $self->{reconnect_attempts}) {
                     croak "Log4perl: DBI appender failed to " .
                           ($self->{reconnect_attempts} == 1 ? "" : "re") .
@@ -157,9 +157,7 @@ sub query_execute {
                           "to database after " .
                           "$self->{reconnect_attempts} attempt" .
                           ($self->{reconnect_attempts} == 1 ? "" : "s") .
-                          " (last error error was [" .
-                          $self->{dbh}->errstr() . 
-                          "])";
+                          " (last error error was [$errstr]";
                 }
             if(! $self->{dbh}->ping()) {
                 # Ping failed, try to reconnect
@@ -186,7 +184,7 @@ sub query_execute {
         }
         return 1;
     }
-    croak "Log4perl: DBI->execute failed $DBI::errstr, \n".
+    croak "Log4perl: DBI->execute failed $errstr, \n".
           "on $self->{SQL}\n @qmarks";
 }
 
@@ -322,35 +320,34 @@ Log::Log4perl::Appender::DBI - implements appending to a DB
 
 =head1 SYNOPSIS
 
-    my $config = <<'EOT';
-    log4j.category = WARN, DBAppndr
-    log4j.appender.DBAppndr             = Log::Log4perl::Appender::DBI
-    log4j.appender.DBAppndr.datasource  = DBI:CSV:f_dir=t/tmp
-    log4j.appender.DBAppndr.username    = bobjones
-    log4j.appender.DBAppndr.password    = 12345
-    log4j.appender.DBAppndr.sql         = \
-       insert into log4perltest           \
-       (loglevel, custid, category, message, ipaddr) \
-       values (?,?,?,?,?)
-    log4j.appender.DBAppndr.params.1 = %p    
-                                  #2 is custid from the log() call
-    log4j.appender.DBAppndr.params.3 = %c
-                                  #4 is the message from log()
-                                  #5 is ipaddr from log()
-        
-    
-    log4j.appender.DBAppndr.usePreparedStmt = 1
-     #--or--
-    log4j.appender.DBAppndr.bufferSize = 2
-    
-    #just pass through the array of message items in the log statement 
-    log4j.appender.DBAppndr.layout    = Log::Log4perl::Layout::NoopLayout
-    log4j.appender.DBAppndr.warp_message = 0
-    
-    
+    my $config = q{
+     log4j.category = WARN, DBAppndr
+     log4j.appender.DBAppndr             = Log::Log4perl::Appender::DBI
+     log4j.appender.DBAppndr.datasource  = DBI:CSV:f_dir=t/tmp
+     log4j.appender.DBAppndr.username    = bobjones
+     log4j.appender.DBAppndr.password    = 12345
+     log4j.appender.DBAppndr.sql         = \
+        insert into log4perltest           \
+        (loglevel, custid, category, message, ipaddr) \
+        values (?,?,?,?,?)
+     log4j.appender.DBAppndr.params.1 = %p    
+                                   #2 is custid from the log() call
+     log4j.appender.DBAppndr.params.3 = %c
+                                   #4 is the message from log()
+                                   #5 is ipaddr from log()
+         
+     
+     log4j.appender.DBAppndr.usePreparedStmt = 1
+      #--or--
+     log4j.appender.DBAppndr.bufferSize = 2
+     
+     #just pass through the array of message items in the log statement 
+     log4j.appender.DBAppndr.layout    = Log::Log4perl::Layout::NoopLayout
+     log4j.appender.DBAppndr.warp_message = 0
+    };
+     
     $logger->warn( $custid, 'big problem!!', $ip_addr );
 
-
 =head1 CAVEAT
 
 This is a very young module and there are a lot of variations
