@@ -98,8 +98,12 @@ use the C<rrdupd_params> configuration parameter:
 To read out the round robin database later on, use C<rrdtool fetch>
 or C<rrdtool graph> for graphic displays.
 
-=head1 AUTHOR
+=head1 COPYRIGHT AND LICENSE
 
-Mike Schilli <log4perl@perlmeister.com>, 2004
+Copyright 2002-2009 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+and Kevin Goess E<lt>cpan@goess.orgE<gt>.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =cut
